@@ -2,5 +2,6 @@ from .pubmed import downloader as pubmed
 from .semantic_scholar import downloader as semanticScholar
 from .icite import downloader as icite
 from .id_converter import downloader as doi2pmid
+from .hf_embed import downloader as hfembed
 
-__all__ = [pubmed, semanticScholar, icite, doi2pmid]
+__all__ = [pubmed, semanticScholar, icite, doi2pmid, hfembed]
